# PyGFET

Tools for GFETs


## install

```
python setup.py install
```

```
pip install PyGFET
```

## Requeriments

* numpy
* matplotlib
* quantities
* scipy
* neo>=0.5.2
* nixio


## Launchers

* PyDBView

